@@ -876,8 +876,8 @@ class BaseFrameContainer extends Core
 						// カテゴリー用テンプレート取得
 						$template = get_category_template();
 						if (empty($template)) $template = get_archive_template();		// カテゴリー用のテンプレートが取得できない場合はアーカイブ用テンプレートを取得
-						$wpIndexFile = $template;
-						
+						if (!empty($template)) $wpIndexFile = $template;
+
 						// フルパスで返るので相対パスに修正
 						//$defaultIndexFile = $this->_getRelativeTemplateIndexPath($curTemplate, $template);		// カテゴリーテンプレート
 						
@@ -895,7 +895,7 @@ class BaseFrameContainer extends Core
 							// 年月日用テンプレート取得
 							$template = get_date_template();
 							if (empty($template)) $template = get_archive_template();		// 年月日用のテンプレートが取得できない場合はアーカイブ用テンプレートを取得
-							$wpIndexFile = $template;		// 記事詳細テンプレート
+							if (!empty($template)) $wpIndexFile = $template;
 						
 							// フルパスで返るので相対パスに修正
 							//$defaultIndexFile = $this->_getRelativeTemplateIndexPath($curTemplate, $template);
@@ -912,7 +912,8 @@ class BaseFrameContainer extends Core
 					
 							// フルパスで返るので相対パスに修正
 							//$defaultIndexFile = $this->_getRelativeTemplateIndexPath($curTemplate, get_search_template());		// 検索結果テンプレート
-							$wpIndexFile = get_search_template();		// 検索結果テンプレート
+							$template = get_search_template();		// 検索結果テンプレート
+							if (!empty($template)) $wpIndexFile = $template;
 							
 							$pageTypeDefined = true;		// ページタイプ確定
 						}
@@ -928,14 +929,46 @@ class BaseFrameContainer extends Core
 			case M3_VIEW_TYPE_PHOTO:	// フォトギャラリー
 				break;
 			default:
+				// 検索キーワードが設定されている場合は検索結果画面を表示
+				$value = $request->trimValueOf('s');
+				if (!empty($value)){
+					// ページ指定されていない場合(フロント画面等)、検索結果表示用ページがある場合はリダイレクト
+					$subId = $request->trimValueOf(M3_REQUEST_PARAM_PAGE_SUB_ID);
+					if (empty($subId)){
+						$subId = $this->_db->getSubPageIdWithContent(M3_VIEW_TYPE_SEARCH, $this->gEnv->getCurrentPageId());// ページサブIDを取得
+						if (!empty($subId)){
+							// リダイレクト用URLを作成
+							$redirectUrl = $this->gEnv->createPageUrl();
+							$redirectUrl .= '?' . M3_REQUEST_PARAM_PAGE_SUB_ID . '=' . $subId;
+							//$redirectUrl .= '&s=' . urlencode($value);							// 検索キーワード
+							$redirectUrl .= '&' . M3_REQUEST_PARAM_OPERATION_TASK . '=search&' . M3_REQUEST_PARAM_KEYWORD . '=' . urlencode($value);		// 検索キーワード
+							
+							$this->gPage->redirect($redirectUrl);
+							return;				// ここで終了
+						}
+					}
+//				} else {
+//					// 検索キーワードが設定されている場合は画面タイトルを設定
+//					$value = $request->trimValueOf(M3_REQUEST_PARAM_KEYWORD);
+//					if (!empty($value)){
+//					}
+				}
+				
+				// ##### デフォルトのページタイトルを設定 #####
+				$pageInfo = $this->gPage->getCurrentPageInfo();
+				if (!empty($pageInfo)){
+					$pageTitle = $pageInfo['pg_name'];
+					if (!empty($pageTitle)) $GLOBALS['gContentApi']->setPostTitle($pageTitle);
+				}
+				
 				// コンテンツタイプが設定されていないページ(お問合わせページ等)に場合は、固定ページ用のテンプレートを使用
 				// ページタイプを設定
 				$GLOBALS['gContentApi']->setPageType('page');
-					
+				
 				// フルパスで返るので相対パスに修正
 				//$defaultIndexFile = $this->_getRelativeTemplateIndexPath($curTemplate, get_page_template());		// 固定ページテンプレート
 				$wpIndexFile = get_page_template();		// 固定ページテンプレート
-				
+			
 				$pageTypeDefined = true;		// ページタイプ確定
 				break;
 			}
@@ -960,7 +993,7 @@ class BaseFrameContainer extends Core
 					}
 				}
 			}
-			
+
 			// プラグインからの起動ファイルパス変換
 			$wpIndexFile = apply_filters('template_include', $wpIndexFile);
 
@@ -1471,8 +1504,9 @@ class BaseFrameContainer extends Core
 			
 			// グローバル変数に変換
 			$vars = get_defined_vars();
-			foreach($vars as $varName => $varValue) $GLOBALS[$varName] = $varValue;
-			
+			foreach($vars as $varName => $varValue){
+				if (!isset($GLOBALS[$varName])) $GLOBALS[$varName] = $varValue;
+			}
 			return true;
 		} else {
 			return false;
