@@ -184,6 +184,9 @@ class admin_mainAccesslogWidgetContainer extends admin_mainConditionBaseWidgetCo
 		$endNextDt = $this->endDt;
 		if (!empty($endNextDt)) $endNextDt = $this->getNextDay($endNextDt);			// 翌日を取得
 		
+		// アクセス元IPを取得
+		$ip = $request->trimValueOf('ip');
+		
 		// 表示条件
 		$maxListCount = $request->trimIntValueOf('viewcount', '0');
 		if (empty($maxListCount)) $maxListCount = self::DEFAULT_LIST_COUNT;				// 表示項目数
@@ -193,6 +196,10 @@ class admin_mainAccesslogWidgetContainer extends admin_mainConditionBaseWidgetCo
 		if (!empty($this->startDt) && !empty($this->endDt) && $this->startDt > $this->endDt){
 			$this->setUserErrorMsg('期間の指定範囲にエラーがあります。');
 		}
+		if (!empty($ip)){
+			$value = filter_var($ip, FILTER_VALIDATE_IP);
+			if ($value === false) $this->setUserErrorMsg('IPの指定にエラーがあります。');
+		}
 		
 		// 総数を取得
 		$pathParam = $this->path;
@@ -201,7 +208,7 @@ class admin_mainAccesslogWidgetContainer extends admin_mainConditionBaseWidgetCo
 		} else if ($pathParam == self::ACCESS_PATH_OTHER){		// その他のパス
 			$pathParam = '';
 		}
-		$totalCount = $this->db->getAccessLogCount($pathParam, $this->startDt, $endNextDt);
+		$totalCount = $this->db->getAccessLogCount($pathParam, $this->startDt, $endNextDt, $ip);
 		
 		// ページング計算
 		$this->calcPageLink($pageNo, $totalCount, $maxListCount);
@@ -210,6 +217,7 @@ class admin_mainAccesslogWidgetContainer extends admin_mainConditionBaseWidgetCo
 		$detailUrl = '?task=accesslog&path=' . $this->path;
 		if (!empty($this->startDt)) $detailUrl .= '&start_date=' . $this->startDt;	// 検索範囲開始日付
 		if (!empty($this->endDt)) $detailUrl .= '&end_date=' . $this->endDt;		// 検索範囲終了日付
+		if (!empty($ip)) $detailUrl .= '&ip=' . $ip;		// アクセス元IP
 		$pageLink = $this->createPageLink($pageNo, self::LINK_PAGE_COUNT, $detailUrl);
 		
 		// アクセスパスメニュー作成
@@ -224,7 +232,7 @@ class admin_mainAccesslogWidgetContainer extends admin_mainConditionBaseWidgetCo
 		$this->tmpl->addVar("_widget", "view_count", $maxListCount);	// 最大表示項目数
 		
 		// アクセスログを取得
-		$this->db->getAccessLogList($maxListCount, $pageNo, $pathParam, array($this, 'logListLoop'), $this->startDt, $endNextDt);
+		$this->db->getAccessLogList($maxListCount, $pageNo, $pathParam, array($this, 'logListLoop'), $this->startDt, $endNextDt, $ip);
 		$this->tmpl->addVar("_widget", "serial_list", implode($this->serialArray, ','));// 表示項目のシリアル番号を設定
 		if (count($this->serialArray) == 0) $this->tmpl->setAttribute('loglist', 'visibility', 'hidden');		// ログがないときは非表示
 	}
@@ -249,7 +257,27 @@ class admin_mainAccesslogWidgetContainer extends admin_mainConditionBaseWidgetCo
 		$requestParamStr = '';			// 受信リクエスト
 		
 		$reloadData = false;		// データの再読み込み
-		if ($act == 'update'){		// 行更新のとき
+		if ($act == 'gethostname'){		// ホスト名取得のとき
+			// 設定データを取得
+			$ret = $this->db->getAccessLog($this->serialNo, $row);
+			if ($ret){
+				$ip = $row['al_ip'];
+				
+				// ホスト名取得
+				$hostname = gethostbyaddr($ip);
+				if ($hostname === false || $hostname == $ip){			// ホスト名が取得できないとき
+					$hostname = '<span style="color:red">[取得不可]</span>';
+				} else {		// ホスト名が取得できた場合は正引きでIPをチェック
+					$ret = $this->checkHostname($hostname, $ip);
+					if ($ret){
+						$hostname = $this->convertToDispString($hostname);
+					} else {
+						$hostname = '<span style="color:red">[正引き失敗]</span>';
+					}
+				}
+			}
+			
+			$reloadData = true;		// データの再読み込み
 		} else {
 			if (!empty($this->serialNo)) $reloadData = true;		// データの再読み込み
 		}
@@ -338,11 +366,22 @@ class admin_mainAccesslogWidgetContainer extends admin_mainConditionBaseWidgetCo
 			$user = $this->convertToDispString($userName . '(' . $userId . ')');
 		}
 		
+		// ホスト名設定
+		if (!empty($hostname)){
+			$this->tmpl->setAttribute('show_hostname', 'visibility', 'visible');
+			$this->tmpl->addVar("show_hostname", "hostname", $hostname);
+			
+			// 「取得」ボタンを非表示にする
+			$this->tmpl->setAttribute('show_hostname_button', 'visibility', 'hidden');
+		}
+		
 		// 取得データを設定
 		$this->tmpl->addVar("_widget", "serial", $this->serialNo);
 		$this->tmpl->addVar("_widget", "user", $user);
 		$this->tmpl->addVar("_widget", "uri", $this->convertToDispString($uri));
+		$this->tmpl->addVar("_widget", "uri_title", $this->convertToDispString(urldecode($uri)));		// URIデコードタイトル
 		$this->tmpl->addVar("_widget", "referer", $this->convertToDispString($referer));
+		$this->tmpl->addVar("_widget", "referer_title", $this->convertToDispString(urldecode($referer)));	// リファラーデコードタイトル
 		$this->tmpl->addVar("_widget", "ip", $this->convertToDispString($ip));
 		$this->tmpl->addVar("_widget", "request", $requestParamStr);
 		$this->tmpl->addVar("_widget", "agent", $this->convertToDispString($agent));
@@ -382,8 +421,10 @@ class admin_mainAccesslogWidgetContainer extends admin_mainConditionBaseWidgetCo
 		$ip = $fetchedRow['al_ip'];
 		$ipStr = $this->convertToDispString($ip);
 		if ($ip == $this->clientIp){			// クライアントのIPアドレスと同じときはグリーンで表示
-			$ipStr = '<font color="green">' . $ipStr . '</font>';
+			$ipStr = '<span style="color:green;">' . $ipStr . '</span>';
 		}
+		$ipLinkUrl = '?task=accesslog&ip=' . $ip;
+		$ipLink = '<a href="' . $this->convertUrlToHtmlEntity($ipLinkUrl) . '">' . $ipStr . '</a>';
 		
 		// ブラウザ、プラットフォームの情報を取得
 		if ($agent != $savedAgent) $this->browserTypeInfo = $this->gInstance->getAnalyzeManager()->getBrowserType($agent);
@@ -443,7 +484,7 @@ class admin_mainAccesslogWidgetContainer extends admin_mainConditionBaseWidgetCo
 			'browser' => $browserImg,		// ブラウザ
 			'os' => $osImg,			// OS
 			'country' => $countryImg,		// 国画像
-			'ip' => $ipStr,		// クライアントIP
+			'ip' => $ipLink,		// クライアントIP
 			'user' => $userIconHtml,										// ユーザ
 			'dt' => $this->convertToDispDateTime($fetchedRow['al_dt']),	// 出力日時
 			'selected' => $selected												// 項目選択用ラジオボタン
@@ -519,5 +560,31 @@ class admin_mainAccesslogWidgetContainer extends admin_mainConditionBaseWidgetCo
 		$this->tmpl->parseTemplate('path_list', 'a');
 		return true;
 	}
+	/**
+	 * ホスト名のクライアントが指定のIPアドレスであるかチェック
+	 *
+	 * @param string $hostname		ホスト名
+	 * @param string $ip			IPアドレス
+	 * @return bool					true=適合する、false=適合しない
+	 */
+	function checkHostname($hostname, $ip)
+	{
+		$ipArray = false;
+		
+		if (filter_var($ip, FILTER_VALIDATE_IP, FILTER_FLAG_IPV6)){	// IPがIPv6の場合
+			$rows = @dns_get_record($hostname, DNS_AAAA);
+			if ($rows){
+				$ipArray = array_map(function ($v){ return $v['ipv6']; }, $rows);
+			}
+		} else if (filter_var($ip, FILTER_VALIDATE_IP, FILTER_FLAG_IPV4)){	// IPがIPv4の場合
+			$ipArray = gethostbynamel($hostname);
+		}
+		
+		if ($ipArray && in_array($ip, $ipArray)){
+			return true;
+		} else {
+			return false;
+		}
+	}
 }
 ?>
