@@ -8,7 +8,7 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2015 Magic3 Project.
+ * @copyright  Copyright 2006-2017 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
  * @version    SVN: $Id$
  * @link       http://www.magic3.org
@@ -717,7 +717,7 @@ class Link_autolink extends Link
 		list($name) = $this->splice($arr);
 
 		// Ignore pages listed, or Expire ones not found
-		if (in_array($name, $this->forceignorepages) || ! is_page($name)) return FALSE;
+		if (in_array($name, $this->forceignorepages) || ! WikiPage::isPage($name)) return FALSE;
 		
 		return parent::setParam($page, $name, '', 'pagename', $name);
 	}
@@ -762,9 +762,9 @@ function make_pagelink($page, $alias = '', $anchor = '', $refer = '', $isautolin
 
 	$r_refer = ($refer == '') ? '' : '&amp;refer=' . rawurlencode($refer);
 
-	if (! isset($related[$page]) && $page != $vars['page'] && is_page($page)) $related[$page] = get_filetime($page);
+	if (! isset($related[$page]) && $page != $vars['page'] && WikiPage::isPage($page)) $related[$page] = get_filetime($page);
 
-	if ($isautolink || is_page($page)) {
+	if ($isautolink || WikiPage::isPage($page)) {
 		// Hyperlink to the page
 		if ($link_compact) {
 			$title   = '';
